Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_5_1_sq
   :fromid: mucp_5_1, mucp_5_1_ac_q
   :toggle:

.. selectquestion:: mucp_5_2_sq
   :fromid: mucp_5_2, mucp_5_2_ac_q
   :toggle:

.. selectquestion:: mucp_5_3_sq
   :fromid: mucp_5_3, mucp_5_3_ac_q
   :toggle:

.. selectquestion:: mucp_5_4_sq
   :fromid: mucp_5_4, mucp_5_4_ac_q
   :toggle:

.. selectquestion:: mucp_5_5_sq
   :fromid: mucp_5_5, mucp_5_5_ac_q
   :toggle:

.. selectquestion:: mucp_5_6_sq
   :fromid: mucp_5_6, mucp_5_6_ac_q
   :toggle:

.. selectquestion:: mucp_5_7_sq
   :fromid: mucp_5_7, mucp_5_7_ac_q
   :toggle:

.. selectquestion:: mucp_5_8_sq
   :fromid: mucp_5_8, mucp_5_8_ac_q
   :toggle:

.. selectquestion:: mucp_5_9_sq
   :fromid: mucp_5_9, mucp_5_9_ac_q
   :toggle:

.. selectquestion:: mucp_5_10_sq
   :fromid: mucp_5_10, mucp_5_10_ac_q
   :toggle:

.. selectquestion:: mucp_5_11_sq
   :fromid: mucp_5_11, mucp_5_11_ac_q
   :toggle:
